﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO;

namespace WeatherGMap
{
    public partial class Form1 : Form
    {
        public List<WOEID> woeidList = null;

        public void LoadImageList(string path, ref ImageList imageList)
        {
            // load files & add new data
            imageList.ColorDepth = System.Windows.Forms.ColorDepth.Depth24Bit;
            imageList.ImageSize = new System.Drawing.Size(30, 30);
            imageList.TransparentColor = System.Drawing.Color.Transparent;

            DirectoryInfo dir = new DirectoryInfo(path);
            foreach (FileInfo file in dir.GetFiles())
            {
                try
                {
                    imageList.Images.Add(Image.FromFile(file.FullName));
                    System.Diagnostics.Trace.WriteLine("image loaded: " + file.FullName);
                }
                catch
                {
                    Console.WriteLine("Failed to retrieve files");
                }
            }
        }

        public Form1()
        {
            InitializeComponent();
            LoadImageList("..\\..\\Resources", ref imageList1);
            listView1.SmallImageList = imageList1;
            this.listView1.Columns.AddRange(WOEID.ToListViewColumnHeader());
        }

        private void Form1_Load(object sender, EventArgs e)
        {
        }

        private void closeToolStripMenuItem_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void newToolStripMenuItem_Click(object sender, EventArgs e)
        {
            listView1.Items.Clear();
            woeidList.Clear();
        }

        private void listView1_ColumnClick(object sender, ColumnClickEventArgs e)
        {
            listView1.ListViewItemSorter = new ListViewItemComparer(e.Column);
            listView1.Sort();
            SortList(e.Column);
        }

        private void SortList(int column)
        {
            if (column == 0)
                woeidList.Sort(); // (p, q) => p.Code.CompareTo(q.Code));
            else if (column == 1)
                woeidList.Sort((p, q) => p.City.CompareTo(q.City));
            else if (column == 2)
                woeidList.Sort((p, q) => p.Country.CompareTo(q.Country));
            else if (column == 3)
                woeidList.Sort((p, q) => p.Latitude.CompareTo(q.Latitude));
            else if (column == 4)
                woeidList.Sort((p, q) => p.Longitude.CompareTo(q.Longitude));
        }

        private void saveXMLToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (saveFileDialog1.ShowDialog() == DialogResult.OK)
            {
                WOEIDImporter.SaveXML(saveFileDialog1.FileName, woeidList);
            }
        }

        private void openXMLToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (openFileDialog1.ShowDialog() == DialogResult.OK)
            {
                woeidList = WOEIDImporter.LoadXML(openFileDialog1.FileName);
                woeidList.ForEach(w => listView1.Items.Add(w.ToListViewItem()));
            }
        }

        private void openJSONToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (openFileDialog1.ShowDialog() == DialogResult.OK)
            {
                woeidList = WOEIDImporter.LoadJSON(openFileDialog1.FileName);
                woeidList.ForEach(w => listView1.Items.Add(w.ToListViewItem()));
                listView1.Refresh();
            }
        }

        private void saveJsonToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (saveFileDialog1.ShowDialog() == DialogResult.OK)
            {
                WOEIDImporter.WriteJSON(saveFileDialog1.FileName, woeidList);
            }
        }

        private void openToolStripMenuItem1_Click(object sender, EventArgs e)
        {
            if (openFileDialog1.ShowDialog() == DialogResult.OK)
            {
                System.Diagnostics.Trace.WriteLine("Filename=" + openFileDialog1.FileName);
                woeidList = WOEIDImporter.LoadCSV(openFileDialog1.FileName);
                woeidList.ForEach(w => listView1.Items.Add(w.ToListViewItem()));
                for (int i = 0; i < woeidList.Count; i++)
                {
                    listView1.Items[i].ImageIndex = i % 47;
                }
                listView1.Refresh();
            }
        }

        private void sAVECSVToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (saveFileDialog1.ShowDialog() == DialogResult.OK)
            {
                WOEIDImporter.SaveCSV(saveFileDialog1.FileName, woeidList);
            }
        }

        private void sveBINToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (saveFileDialog1.ShowDialog() == DialogResult.OK)
            {
                WOEIDImporter.WriteBIN(saveFileDialog1.FileName, woeidList);
            }
        }

        private void openBINToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (openFileDialog1.ShowDialog() == DialogResult.OK)
            {
                woeidList = WOEIDImporter.LoadBIN(openFileDialog1.FileName);
                woeidList.ForEach(w => listView1.Items.Add(w.ToListViewItem()));
                listView1.Refresh();
            }
        }
    }
}
