﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Xml.Serialization;
using System.Runtime.Serialization;

namespace WeatherGMap
{
    [Serializable]
    public class WOEID : IComparable<WOEID>, ISerializable
    {
        [XmlElement("Code")]
        public long Code  {  get; set;   }
        [XmlElement("City")]
        public string City { get; set;   }
        [XmlElement("Country")]
        public string Country { get; set; }
        [XmlElement("Latitude")]
        public double Latitude { get; set; }
        [XmlElement("Longitude")]
        public double Longitude { get; set; }
        public WOEID() : this(0, "", "", 0.0, 0.0) { }
        public WOEID(long code, string city, string country, double latitude, double longitude)
        {
            Code = code;
            City = city;
            Country = country;
            Latitude = latitude;
            Longitude = longitude;
        }

        public override string ToString()
        {
            return string.Format("{0},{1},{2},{3},{4}", Code, City, Country, Latitude, Longitude);
        }

        public static ColumnHeader[] ToListViewColumnHeader()
        {
            ColumnHeader[] headers = new ColumnHeader[] 
            {
                new ColumnHeader() { Text = "Code", Width = 120 },
                new ColumnHeader() { Text = "City", Width = 150 },
                new ColumnHeader() { Text = "Country", Width = 150 },
                new ColumnHeader() { Text = "Latitude", Width = 120 },
                new ColumnHeader() { Text = "Longitude", Width = 120 }
            };
            return headers;
        }

        public ListViewItem ToListViewItem()
        {
            ListViewItem item = new ListViewItem(Code.ToString());
            item.SubItems.Add(new ListViewItem.ListViewSubItem(item, City));
            item.SubItems.Add(new ListViewItem.ListViewSubItem(item, Country));
            item.SubItems.Add(new ListViewItem.ListViewSubItem(item, Latitude.ToString()));
            item.SubItems.Add(new ListViewItem.ListViewSubItem(item, Longitude.ToString()));
            return item;
        }

        public int CompareTo(WOEID other)
        {
            return Code.CompareTo(other.Code);
        }
        // serialize
        public virtual void GetObjectData(
            SerializationInfo info, StreamingContext context)
        {
            info.AddValue("Code", Code);
            info.AddValue("City", City);
            info.AddValue("Country", Country);
        }
        // deserialize
        protected virtual void SetObjectData(
            SerializationInfo info, StreamingContext context)
        {
            Code = info.GetInt64("Code");
            City = info.GetString("City");
            Country = info.GetString("Country");
        }
        protected WOEID(SerializationInfo info, StreamingContext context)
        {
            SetObjectData(info, context);
        }
    }
}
