﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.IO;
using System.Xml.Serialization;
using System.Web.Script.Serialization;
using Newtonsoft.Json;
using System.Runtime.Serialization.Formatters.Binary;

namespace WeatherGMap
{
    public class WOEIDImporter
    {
        public static List<WOEID> LoadData()
        {
            List<WOEID> woeidList = new List<WOEID>();
            woeidList.Add(new WOEID());
            woeidList.Add(new WOEID(12, "MM", "DKU", 20.5, 40.5));
            return woeidList;
        }

        public static List<WOEID> LoadCSV(string filename)
        {
            List<WOEID> woeidList = new List<WOEID>();
            if (File.Exists(filename))
            {
                System.Diagnostics.Trace.WriteLine(filename);

                using (StreamReader sr = 
                    new StreamReader(filename, System.Text.Encoding.Default))
                {
                    string line = "";
                    char[] delimiter = { ',' }; // CSV
                    while ((line = sr.ReadLine()) != null)
                    {
                        //System.Diagnostics.Trace.WriteLine(line);
                        string[] items = line.Split(delimiter);
                        long code = long.Parse(items[0]);
                        string city = items[1];
                        string country = items[2];
                        double lat = double.Parse(items[3]);
                        double lon = double.Parse(items[4]);
                        woeidList.Add(new WOEID(code, city, country, lat, lon));
                    }
                }
            }
            return woeidList;
        }

        public static void SaveCSV(string filename, List<WOEID> woeidList)
        {
            using (StreamWriter sw = 
                new StreamWriter(filename, false, System.Text.Encoding.Default))
            {
                woeidList.ForEach(w => sw.WriteLine(w));
                sw.Close();
            }
        }
        public static List<WOEID> LoadXML(string filename)
        {
            // XML serialize
            using (FileStream fs = new FileStream(filename, FileMode.Open, FileAccess.Read))
            {
                XmlSerializer xs = new XmlSerializer(typeof(List<WOEID>));
                List<WOEID> woeidList = (List<WOEID>)xs.Deserialize(fs);
                fs.Close();
                return woeidList;
            }
        }
        public static void SaveXML(string filename, List<WOEID> woeidList)
        {
            // XML serialize
            using (FileStream fs = new FileStream(filename, FileMode.Create, FileAccess.Write))
            {
                XmlSerializer xs = new XmlSerializer(typeof(List<WOEID>));
                xs.Serialize(fs, woeidList);
                fs.Close();
            }
        }
        public static List<WOEID> LoadJSON(string filename)
        {
            List<WOEID> woeidList = null;
            using (StreamReader sr = 
                new StreamReader(filename, System.Text.Encoding.Default))
            {
                string json = sr.ReadToEnd();
                if (json != null)
                {
                    JavaScriptSerializer deserializer = 
                        new JavaScriptSerializer();
                    woeidList = 
                        deserializer.Deserialize<List<WOEID>>(json);
                }
                sr.Close();
            }
            return woeidList;
        }
        public static void WriteJSON(string filename, List<WOEID> woeidList)
        {
            using (StreamWriter sw =
                new StreamWriter(filename, false, System.Text.Encoding.Default))
            {
                string jsonStringfy = 
                    JsonConvert.SerializeObject(woeidList.ToArray(), Formatting.Indented);
                sw.WriteLine(jsonStringfy);
                sw.Close();
            }
        }

        public static void WriteBIN(string filename, List<WOEID> woeidList)
        {
            using (FileStream fs =
                new FileStream(filename, FileMode.Create, FileAccess.Write))
            {
                BinaryFormatter bf = new BinaryFormatter();
                bf.Serialize(fs, woeidList);
                fs.Close();
            }
        }
        public static List<WOEID> LoadBIN(string filename)
        {
            List<WOEID> woeidList = null;
            using (FileStream fs = 
                new FileStream(filename, FileMode.Open, FileAccess.Read))
            {
                BinaryFormatter bf = new BinaryFormatter();
                woeidList = (List<WOEID>)bf.Deserialize(fs);
                fs.Close();
            }
            return woeidList;
        }
    }
}
